1.1.2
=====

Refresh packaging.

1.1.1
=====

#2: Fixed issue where ``gzip.load_streams`` would get into
an infinite loop at the end of every stream.

1.1
===

Declared compatibility with Python 2.7 and gzip module now
is also Python 2.7 compatible.

1.0
===

Initial release with gzip and buffer module.
